Fixed a typo in my previous commit

This commit is contained in:
Benoit Steiner
2016-05-11 10:22:15 -07:00
parent 08348b4e48
commit 217d984abc
5 changed files with 63 additions and 3 deletions

View File

@@ -318,7 +318,7 @@ __global__ void InnerReductionKernel(Reducer reducer, const Self input, Index nu
for (Index i = thread_id; i < num_preserved_coeffs; i += num_threads) {
output[i] = reducer.initialize();
}
_syncthreads();
__syncthreads();
}
for (Index i = blockIdx.x; i < num_input_blocks; i += gridDim.x) {